@@ -181,7 +181,7 @@ class PyScanner(MF):
                 f = os.path.join(d,f)
                 if os.path.exists(f): imports.append(f)
         
-        imports = [i for i in imports if "/site-packages/" not in i]
+        imports = [i for i in imports if "/site-packages/" not in i and "/SCons/" not in i]
 
         imports = list(os.path.abspath(m) for m in imports if self.path_filter(m))
         return imports
